Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(130)

Unified Diff: ipc/ipc_channel_proxy_unittest.cc

Issue 324143002: Decouple IPC::MessageFilter from IPC::Channel (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fixing compilation errors Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ipc/ipc_channel_proxy_unittest.cc
diff --git a/ipc/ipc_channel_proxy_unittest.cc b/ipc/ipc_channel_proxy_unittest.cc
index 20e42e30224efbb57dfd8970472c18d714983816..346f43eca4366db7b20d5c7f10354894f3fa8d0c 100644
--- a/ipc/ipc_channel_proxy_unittest.cc
+++ b/ipc/ipc_channel_proxy_unittest.cc
@@ -143,26 +143,25 @@ class MessageCountFilter : public IPC::MessageFilter {
last_filter_event_(NONE),
message_filtering_enabled_(false) {}
- virtual void OnFilterAdded(IPC::Channel* channel) OVERRIDE {
- EXPECT_TRUE(channel);
+ virtual void OnFilterAdded(IPC::Sender* sender) OVERRIDE {
+ EXPECT_TRUE(sender);
EXPECT_EQ(NONE, last_filter_event_);
last_filter_event_ = FILTER_ADDED;
}
- virtual void OnChannelConnected(int32_t peer_pid) OVERRIDE {
+ virtual void OnSenderConnected() OVERRIDE {
EXPECT_EQ(FILTER_ADDED, last_filter_event_);
- EXPECT_NE(static_cast<int32_t>(base::kNullProcessId), peer_pid);
last_filter_event_ = CHANNEL_CONNECTED;
}
- virtual void OnChannelError() OVERRIDE {
+ virtual void OnSenderError() OVERRIDE {
EXPECT_EQ(CHANNEL_CONNECTED, last_filter_event_);
last_filter_event_ = CHANNEL_ERROR;
}
- virtual void OnChannelClosing() OVERRIDE {
- // We may or may not have gotten OnChannelError; if not, the last event has
- // to be OnChannelConnected.
+ virtual void OnSenderClosing() OVERRIDE {
+ // We may or may not have gotten OnSenderError; if not, the last event has
+ // to be OnSenderConnected.
if (last_filter_event_ != CHANNEL_ERROR)
EXPECT_EQ(CHANNEL_CONNECTED, last_filter_event_);
last_filter_event_ = CHANNEL_CLOSING;
« no previous file with comments | « ipc/ipc_channel_proxy.cc ('k') | ipc/ipc_sync_channel_unittest.cc » ('j') | ipc/message_filter.h » ('J')

Powered by Google App Engine
This is Rietveld 408576698